"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
/**
 * ZjsError
 *
 * Custom error for use with ZJS modules.
 *
 * @extends {Error}
 */
var ZjsError = /** @class */ (function (_super) {
    tslib_1.__extends(ZjsError, _super);
    function ZjsError(message, reason, code, params) {
        if (params === void 0) { params = {}; }
        var _this = _super.call(this, message) || this;
        _this.reason = '';
        _this.reason = reason;
        _this.code = code;
        _this.params = params;
        return _this;
    }
    return ZjsError;
}(Error));
exports.ZjsError = ZjsError;
/**
 * createError
 *
 * Creates a custom ZjsError.
 *
 * This code is adapted from https://github.com/ethers-io/ethers.js/blob/fa68385cfefdc725b4233083e5ba681b8319d78a/src.ts/errors.ts
 *
 * @param {string} reason
 * @param {string} code
 * @param {any} params
 *
 * @returns {ZjsError}
 */
exports.createError = function (reason, code, params) {
    if (code === void 0) { code = "UNKNOWN_ERROR" /* UNKNOWN_ERROR */; }
    if (params === void 0) { params = {}; }
    var details = Object.keys(params).map(function (key) {
        try {
            return key + "=" + JSON.stringify(params[key]);
        }
        catch (error) {
            return key + "=" + JSON.stringify(params[key].toString());
        }
    });
    var message = reason + " (" + details.join(', ') + ")";
    return new ZjsError(message, reason, code, params);
};
//# sourceMappingURL=errors.js.map